@@ -16,12 +16,25 @@ QwtPainterClass
 from qwt.color_map import QwtColorMap
 from qwt.scale_map import QwtScaleMap
 
-from qwt.qt.QtGui import (QPaintEngine, QFrame, QPixmap, QPainter, QPalette, 
-                          QStyle, QPen, QStyleOptionFocusRect, QBrush, 
-                          QLinearGradient, QPainterPath, QColor, QStyleOption)
-from qwt.qt.QtCore import Qt, QRect, QPoint, QT_VERSION
+from qtpy.QtGui import (
+    QPaintEngine,
+    QPixmap,
+    QPainter,
+    QPalette,
+    QPen,
+    QBrush,
+    QRegion,
+    QLinearGradient,
+    QPainterPath,
+    QColor,
+)
+from qtpy.QtWidgets import QFrame, QStyle, QStyleOptionFocusRect, QStyleOption
+from qtpy.QtCore import Qt, QRect, QPoint, QRectF, QLineF
+from qtpy import QtCore as QC
 
-QWIDGETSIZE_MAX = (1<<24)-1
+QT_MAJOR_VERSION = int(QC.__version__.split(".")[0])
+
+QWIDGETSIZE_MAX = (1 << 24) - 1
 
 
 def isX11GraphicsSystem():
@@ -31,6 +44,7 @@ def isX11GraphicsSystem():
     del painter
     return isX11
 
+
 def qwtFillRect(widget, painter, rect, brush):
     if brush.style() == Qt.TexturePattern:
         painter.save()
@@ -48,29 +62,29 @@ def qwtFillRect(widget, painter, rect, brush):
 
 class QwtPainterClass(object):
     """A collection of `QPainter` workarounds"""
-    
+
     def drawImage(self, painter, rect, image):
         alignedRect = rect.toAlignedRect()
         if alignedRect != rect:
-            clipRect = rect.adjusted(0., 0., -1., -1.)
+            clipRect = rect.adjusted(0.0, 0.0, -1.0, -1.0)
             painter.save()
             painter.setClipRect(clipRect, Qt.IntersectClip)
             painter.drawImage(alignedRect, image)
             painter.restore()
         else:
             painter.drawImage(alignedRect, image)
-    
+
     def drawPixmap(self, painter, rect, pixmap):
         alignedRect = rect.toAlignedRect()
         if alignedRect != rect:
-            clipRect = rect.adjusted(0., 0., -1., -1.)
+            clipRect = rect.adjusted(0.0, 0.0, -1.0, -1.0)
             painter.save()
             painter.setClipRect(clipRect, Qt.IntersectClip)
             painter.drawPixmap(alignedRect, pixmap)
             painter.restore()
         else:
             painter.drawPixmap(alignedRect, pixmap)
-    
+
     def drawFocusRect(self, *args):
         if len(args) == 2:
             painter, widget = args
@@ -81,16 +95,19 @@ class QwtPainterClass(object):
             opt.initFrom(widget)
             opt.rect = rect
             opt.state |= QStyle.State_HasFocus
-            widget.style().drawPrimitive(QStyle.PE_FrameFocusRect,
-                                         opt, painter, widget)
+            palette = widget.palette()
+            opt.backgroundColor = palette.color(widget.backgroundRole())
+            widget.style().drawPrimitive(QStyle.PE_FrameFocusRect, opt, painter, widget)
         else:
-            raise TypeError("QwtPainter.drawFocusRect() takes 2 or 3 argument"\
-                            "(s) (%s given)" % len(args))
-    
+            raise TypeError(
+                "QwtPainter.drawFocusRect() takes 2 or 3 argument"
+                "(s) (%s given)" % len(args)
+            )
+
     def drawRoundFrame(self, painter, rect, palette, lineWidth, frameStyle):
         """
         Draw a round frame
-        
+
         :param QPainter painter: Painter
         :param QRectF rect: Target rectangle
         :param QPalette palette: `QPalette.WindowText` is used for plain borders, `QPalette.Dark` and `QPalette.Light` for raised or sunken borders
@@ -103,7 +120,7 @@ class QwtPainterClass(object):
             style = Sunken
         elif (frameStyle & QFrame.Raised) == QFrame.Raised:
             style = Raised
-        lw2 = .5*lineWidth
+        lw2 = 0.5 * lineWidth
         r = rect.adjusted(lw2, lw2, -lw2, -lw2)
         if style != Plain:
             c1 = palette.color(QPalette.Light)
@@ -111,8 +128,8 @@ class QwtPainterClass(object):
             if style == Sunken:
                 c1, c2 = c2, c1
             gradient = QLinearGradient(r.topLeft(), r.bottomRight())
-            gradient.setColorAt(0., c1)
-            gradient.setColorAt(1., c2)
+            gradient.setColorAt(0.0, c1)
+            gradient.setColorAt(1.0, c2)
             brush = QBrush(gradient)
         else:
             brush = palette.brush(QPalette.WindowText)
@@ -120,12 +137,20 @@ class QwtPainterClass(object):
         painter.setPen(QPen(brush, lineWidth))
         painter.drawEllipse(r)
         painter.restore()
-    
-    def drawFrame(self, painter, rect, palette, foregroundRole,
-                  frameWidth, midLineWidth, frameStyle):
+
+    def drawFrame(
+        self,
+        painter,
+        rect,
+        palette,
+        foregroundRole,
+        frameWidth,
+        midLineWidth,
+        frameStyle,
+    ):
         """
         Draw a rectangular frame
-        
+
         :param QPainter painter: Painter
         :param QRectF rect: Frame rectangle
         :param QPalette palette: Palette
@@ -139,9 +164,10 @@ class QwtPainterClass(object):
         shadow = frameStyle & QFrame.Shadow_Mask
         painter.save()
         if shadow == QFrame.Plain:
-            outerRect = rect.adjusted(0., 0., -1., -1.)
+            outerRect = rect.adjusted(0.0, 0.0, -1.0, -1.0)
             innerRect = outerRect.adjusted(
-                            frameWidth, frameWidth, -frameWidth, -frameWidth)
+                frameWidth, frameWidth, -frameWidth, -frameWidth
+            )
             path = QPainterPath()
             path.addRect(outerRect)
             path.addRect(innerRect)
@@ -151,13 +177,16 @@ class QwtPainterClass(object):
         else:
             shape = frameStyle & QFrame.Shape_Mask
             if shape == QFrame.Box:
-                outerRect = rect.adjusted(0., 0., -1., -1.)
+                outerRect = rect.adjusted(0.0, 0.0, -1.0, -1.0)
                 midRect1 = outerRect.adjusted(
-                    frameWidth, frameWidth, -frameWidth, -frameWidth)
+                    frameWidth, frameWidth, -frameWidth, -frameWidth
+                )
                 midRect2 = midRect1.adjusted(
-                    midLineWidth, midLineWidth, -midLineWidth, -midLineWidth)
+                    midLineWidth, midLineWidth, -midLineWidth, -midLineWidth
+                )
                 innerRect = midRect2.adjusted(
-                    frameWidth, frameWidth, -frameWidth, -frameWidth)
+                    frameWidth, frameWidth, -frameWidth, -frameWidth
+                )
                 path1 = QPainterPath()
                 path1.moveTo(outerRect.bottomLeft())
                 path1.lineTo(outerRect.topLeft())
@@ -203,9 +232,13 @@ class QwtPainterClass(object):
                 painter.setBrush(palette.mid())
                 painter.drawPath(path5)
             else:
-                outerRect = rect.adjusted(0., 0., -1., -1.)
-                innerRect = outerRect.adjusted(frameWidth-1., frameWidth-1.,
-                                           -(frameWidth-1.), -(frameWidth-1.))
+                outerRect = rect.adjusted(0.0, 0.0, -1.0, -1.0)
+                innerRect = outerRect.adjusted(
+                    frameWidth - 1.0,
+                    frameWidth - 1.0,
+                    -(frameWidth - 1.0),
+                    -(frameWidth - 1.0),
+                )
                 path1 = QPainterPath()
                 path1.moveTo(outerRect.bottomLeft())
                 path1.lineTo(outerRect.topLeft())
@@ -230,12 +263,13 @@ class QwtPainterClass(object):
                 painter.setBrush(brush2)
                 painter.drawPath(path2)
         painter.restore()
-        
-    def drawRoundedFrame(self, painter, rect, xRadius, yRadius,
-                         palette, lineWidth, frameStyle):
+
+    def drawRoundedFrame(
+        self, painter, rect, xRadius, yRadius, palette, lineWidth, frameStyle
+    ):
         """
         Draw a rectangular frame with rounded borders
-        
+
         :param QPainter painter: Painter
         :param QRectF rect: Frame rectangle
         :param float xRadius: x-radius of the ellipses defining the corners
@@ -247,7 +281,7 @@ class QwtPainterClass(object):
         painter.save()
         painter.setRenderHint(QPainter.Antialiasing, True)
         painter.setBrush(Qt.NoBrush)
-        lw2 = lineWidth*.5
+        lw2 = lineWidth * 0.5
         r = rect.adjusted(lw2, lw2, -lw2, -lw2)
         path = QPainterPath()
         path.addRoundedRect(r, xRadius, yRadius)
@@ -260,23 +294,28 @@ class QwtPainterClass(object):
         if style != Plain and path.elementCount() == 17:
             pathList = [QPainterPath() for _i in range(8)]
             for i in range(4):
-                j = i*4+1
-                pathList[2*i].moveTo(path.elementAt(j-1).x,
-                                     path.elementAt(j-1).y)
-                pathList[2*i].cubicTo(
-                        path.elementAt(j+0).x, path.elementAt(j+0).y,
-                        path.elementAt(j+1).x, path.elementAt(j+1).y,
-                        path.elementAt(j+2).x, path.elementAt(j+2).y)
-                pathList[2*i+1].moveTo(path.elementAt(j+2).x,
-                                       path.elementAt(j+2).y)
-                pathList[2*i+1].lineTo(path.elementAt(j+3).x,
-                                       path.elementAt(j+3).y)
+                j = i * 4 + 1
+                pathList[2 * i].moveTo(path.elementAt(j - 1).x, path.elementAt(j - 1).y)
+                pathList[2 * i].cubicTo(
+                    path.elementAt(j + 0).x,
+                    path.elementAt(j + 0).y,
+                    path.elementAt(j + 1).x,
+                    path.elementAt(j + 1).y,
+                    path.elementAt(j + 2).x,
+                    path.elementAt(j + 2).y,
+                )
+                pathList[2 * i + 1].moveTo(
+                    path.elementAt(j + 2).x, path.elementAt(j + 2).y
+                )
+                pathList[2 * i + 1].lineTo(
+                    path.elementAt(j + 3).x, path.elementAt(j + 3).y
+                )
             c1 = QColor(palette.color(QPalette.Dark))
             c2 = QColor(palette.color(QPalette.Light))
             if style == Raised:
                 c1, c2 = c2, c1
             for i in range(5):
-                r = pathList[2*i].controlPointRect()
+                r = pathList[2 * i].controlPointRect()
                 arcPen = QPen()
                 arcPen.setCapStyle(Qt.FlatCap)
                 arcPen.setWidth(lineWidth)
@@ -290,8 +329,8 @@ class QwtPainterClass(object):
                     gradient = QLinearGradient()
                     gradient.setStart(r.topLeft())
                     gradient.setFinalStop(r.bottomRight())
-                    gradient.setColorAt(0., c1)
-                    gradient.setColorAt(1., c2)
+                    gradient.setColorAt(0.0, c1)
+                    gradient.setColorAt(1.0, c2)
                     arcPen.setBrush(gradient)
                     linePen.setColor(c2)
                 elif i == 2:
@@ -301,25 +340,24 @@ class QwtPainterClass(object):
                     gradient = QLinearGradient()
                     gradient.setStart(r.bottomRight())
                     gradient.setFinalStop(r.topLeft())
-                    gradient.setColorAt(0., c2)
-                    gradient.setColorAt(1., c1)
+                    gradient.setColorAt(0.0, c2)
+                    gradient.setColorAt(1.0, c1)
                     arcPen.setBrush(gradient)
                     linePen.setColor(c1)
                 painter.setPen(arcPen)
-                painter.drawPath(pathList[2*i])
+                painter.drawPath(pathList[2 * i])
                 painter.setPen(linePen)
-                painter.drawPath(pathList[2*i+1])
+                painter.drawPath(pathList[2 * i + 1])
         else:
             pen = QPen(palette.color(QPalette.WindowText), lineWidth)
             painter.setPen(pen)
             painter.drawPath(path)
         painter.restore()
-        
-    def drawColorBar(self, painter, colorMap, interval, scaleMap,
-                     orientation, rect):
+
+    def drawColorBar(self, painter, colorMap, interval, scaleMap, orientation, rect):
         """
         Draw a color bar into a rectangle
-        
+
         :param QPainter painter: Painter
         :param qwt.color_map.QwtColorMap colorMap: Color map
         :param qwt.interval.QwtInterval interval: Value range
@@ -339,42 +377,42 @@ class QwtPainterClass(object):
         if orientation == Qt.Horizontal:
             sMap = QwtScaleMap(scaleMap)
             sMap.setPaintInterval(rect.left(), rect.right())
-            for x in range(devRect.left(), devRect.right()+1):
+            for x in range(devRect.left(), devRect.right() + 1):
                 value = sMap.invTransform(x)
                 if colorMap.format() == QwtColorMap.RGB:
                     c.setRgba(colorMap.rgb(interval, value))
                 else:
                     c = colorTable[colorMap.colorIndex(interval, value)]
                 pmPainter.setPen(c)
-                pmPainter.drawLine(x, devRect.top(), x, devRect.bottom())
+                pmPainter.drawLine(QLineF(x, devRect.top(), x, devRect.bottom()))
         else:
             sMap = QwtScaleMap(scaleMap)
             sMap.setPaintInterval(rect.bottom(), rect.top())
-            for y in range(devRect.top(), devRect.bottom()+1):
+            for y in range(devRect.top(), devRect.bottom() + 1):
                 value = sMap.invTransform(y)
                 if colorMap.format() == QwtColorMap.RGB:
                     c.setRgba(colorMap.rgb(interval, value))
                 else:
                     c = colorTable[colorMap.colorIndex(interval, value)]
                 pmPainter.setPen(c)
-                pmPainter.drawLine(devRect.left(), y, devRect.right(), y)
+                pmPainter.drawLine(QLineF(devRect.left(), y, devRect.right(), y))
         pmPainter.end()
         self.drawPixmap(painter, rect, pixmap)
-    
+
     def fillPixmap(self, widget, pixmap, offset=None):
         """
         Fill a pixmap with the content of a widget
 
         In Qt >= 5.0 `QPixmap.fill()` is a nop, in Qt 4.x it is buggy
-        for backgrounds with gradients. Thus `fillPixmap()` offers 
+        for backgrounds with gradients. Thus `fillPixmap()` offers
         an alternative implementation.
-        
+
         :param QWidget widget: Widget
         :param QPixmap pixmap: Pixmap to be filled
         :param QPoint offset: Offset
-        
+
         .. seealso::
-        
+
             :py:meth:`QPixmap.fill()`
         """
         if offset is None:
@@ -389,58 +427,58 @@ class QwtPainterClass(object):
         if widget.autoFillBackground():
             qwtFillRect(widget, painter, rect, autoFillBrush)
         if widget.testAttribute(Qt.WA_StyledBackground):
-            painter.setClipRegion(rect)
+            painter.setClipRegion(QRegion(rect))
             opt = QStyleOption()
             opt.initFrom(widget)
-            widget.style().drawPrimitive(QStyle.PE_Widget, opt,
-                                         painter, widget)
-    
+            widget.style().drawPrimitive(QStyle.PE_Widget, opt, painter, widget)
+
     def drawBackground(self, painter, rect, widget):
         """
         Fill rect with the background of a widget
-        
+
         :param QPainter painter: Painter
         :param QRectF rect: Rectangle to be filled
         :param QWidget widget: Widget
-        
+
         .. seealso::
-        
+
             :py:data:`QStyle.PE_Widget`, :py:meth:`QWidget.backgroundRole()`
         """
         if widget.testAttribute(Qt.WA_StyledBackground):
             opt = QStyleOption()
             opt.initFrom(widget)
-            opt.rect = rect.toAlignedRect()
-            widget.style().drawPrimitive(QStyle.PE_Widget, opt,
-                                         painter, widget)
+            opt.rect = QRectF(rect).toAlignedRect()
+            widget.style().drawPrimitive(QStyle.PE_Widget, opt, painter, widget)
         else:
             brush = widget.palette().brush(widget.backgroundRole())
             painter.fillRect(rect, brush)
-        
+
     def backingStore(self, widget, size):
         """
         :param QWidget widget: Widget, for which the backinstore is intended
         :param QSize size: Size of the pixmap
         :return: A pixmap that can be used as backing store
         """
-        if QT_VERSION >= 0x050000:
-            pixelRatio = 1.
+        if QT_MAJOR_VERSION >= 5:
+            pixelRatio = 1.0
             if widget and widget.windowHandle():
                 pixelRatio = widget.windowHandle().devicePixelRatio()
             else:
-                from qwt.qt.QtGui import qApp
+                from qtpy.QtGui import qApp
+
                 if qApp is not None:
                     try:
                         pixelRatio = qApp.devicePixelRatio()
                     except RuntimeError:
                         pass
-            pm = QPixmap(size*pixelRatio)
+            pm = QPixmap(size * pixelRatio)
             pm.setDevicePixelRatio(pixelRatio)
         else:
             pm = QPixmap(size)
-        if QT_VERSION < 0x050000 and widget and isX11GraphicsSystem():
+        if QT_MAJOR_VERSION < 5 and widget and isX11GraphicsSystem():
             if pm.x11Info().screen() != widget.x11Info().screen():
                 pm.x11SetScreen(widget.x11Info().screen())
         return pm
 
-QwtPainter = QwtPainterClass()
\ No newline at end of file
+
+QwtPainter = QwtPainterClass()
