@@ -15,7 +15,6 @@ QwtPlotMarker
 
 from qwt.plot import QwtPlot, QwtPlotItem
 from qwt.text import QwtText
-from qwt.painter import QwtPainter
 from qwt.graphic import QwtGraphic
 from qwt.symbol import QwtSymbol
 from qwt.qthelpers import qcolor_from_str
@@ -240,8 +239,9 @@ class QwtPlotMarker(QwtPlotItem):
         self.drawLines(painter, canvasRect, pos)
         if self.__data.symbol and self.__data.symbol.style() != QwtSymbol.NoSymbol:
             sz = self.__data.symbol.size()
+            width, height = int(sz.width()), int(sz.height())
             clipRect = QRectF(
-                canvasRect.adjusted(-sz.width(), -sz.height(), sz.width(), sz.height())
+                canvasRect.adjusted(-width, -height, width, height)
             )
             if clipRect.contains(pos):
                 self.__data.symbol.drawSymbols(painter, [pos])
