@@ -21,14 +21,24 @@ from qwt.plot_layout import QwtPlotLayout
 from qwt.scale_draw import QwtScaleDraw
 from qwt.scale_map import QwtScaleMap
 
-from qwt.qt.QtGui import (QPrinter, QPainter, QImageWriter, QImage, QColor,
-                          QPaintDevice, QTransform, QPalette, QFileDialog,
-                          QPainterPath, QPen)
-from qwt.qt.QtCore import Qt, QRect, QRectF, QObject, QSizeF
-from qwt.qt.QtSvg import QSvgGenerator
-from qwt.qt.compat import getsavefilename
+from qtpy.QtGui import (
+    QPainter,
+    QImageWriter,
+    QImage,
+    QColor,
+    QPaintDevice,
+    QTransform,
+    QPalette,
+    QPainterPath,
+    QPen,
+)
+from qtpy.QtWidgets import QFileDialog
+from qtpy.QtPrintSupport import QPrinter
+from qtpy.QtCore import Qt, QRect, QRectF, QObject, QSizeF
+from qtpy.QtSvg import QSvgGenerator
+from qtpy.compat import getsavefilename
 
-import numpy as np
+import math
 import os.path as osp
 
 
@@ -38,11 +48,11 @@ def qwtCanvasClip(canvas, canvasRect):
     To avoid too much rounding errors better
     calculate it in target device resolution
     """
-    x1 = np.ceil(canvasRect.left())
-    x2 = np.floor(canvasRect.right())
-    y1 = np.ceil(canvasRect.top())
-    y2 = np.floor(canvasRect.bottom())
-    r = QRect(x1, y1, x2-x1-1, y2-y1-1)
+    x1 = math.ceil(canvasRect.left())
+    x2 = math.floor(canvasRect.right())
+    y1 = math.ceil(canvasRect.top())
+    y2 = math.floor(canvasRect.bottom())
+    r = QRect(x1, y1, x2 - x1 - 1, y2 - y1 - 1)
     return canvas.borderPath(r)
 
 
@@ -51,13 +61,14 @@ class QwtPlotRenderer_PrivateData(object):
         self.discardFlags = QwtPlotRenderer.DiscardNone
         self.layoutFlags = QwtPlotRenderer.DefaultLayout
 
+
 class QwtPlotRenderer(QObject):
     """
     Renderer for exporting a plot to a document, a printer
     or anything else, that is supported by QPainter/QPaintDevice
-    
+
     Discard flags:
-    
+
       * `QwtPlotRenderer.DiscardNone`: Render all components of the plot
       * `QwtPlotRenderer.DiscardBackground`: Don't render the background of the plot
       * `QwtPlotRenderer.DiscardTitle`: Don't render the title of the plot
@@ -65,18 +76,18 @@ class QwtPlotRenderer(QObject):
       * `QwtPlotRenderer.DiscardCanvasBackground`: Don't render the background of the canvas
       * `QwtPlotRenderer.DiscardFooter`: Don't render the footer of the plot
       * `QwtPlotRenderer.DiscardCanvasFrame`: Don't render the frame of the canvas
-      
+
     .. note::
-    
+
         The `QwtPlotRenderer.DiscardCanvasFrame` flag has no effect when using
         style sheets, where the frame is part of the background
-    
+
     Layout flags:
-    
+
       * `QwtPlotRenderer.DefaultLayout`: Use the default layout as on screen
       * `QwtPlotRenderer.FrameWithScales`: Instead of the scales a box is painted around the plot canvas, where the scale ticks are aligned to.
     """
-    
+
     # enum DiscardFlag
     DiscardNone = 0x00
     DiscardBackground = 0x01
@@ -85,15 +96,15 @@ class QwtPlotRenderer(QObject):
     DiscardCanvasBackground = 0x08
     DiscardFooter = 0x10
     DiscardCanvasFrame = 0x20
-    
+
     # enum LayoutFlag
     DefaultLayout = 0x00
     FrameWithScales = 0x01
-    
+
     def __init__(self, parent=None):
         QObject.__init__(self, parent)
         self.__data = QwtPlotRenderer_PrivateData()
-    
+
     def setDiscardFlag(self, flag, on=True):
         """
         Change a flag, indicating what to discard from rendering
@@ -102,27 +113,27 @@ class QwtPlotRenderer(QObject):
         :param bool on: On/Off
 
         .. seealso::
-        
-            :py:meth:`testDiscardFlag()`, :py:meth:`setDiscardFlags()`, 
+
+            :py:meth:`testDiscardFlag()`, :py:meth:`setDiscardFlags()`,
             :py:meth:`discardFlags()`
         """
         if on:
             self.__data.discardFlags |= flag
         else:
             self.__data.discardFlags &= ~flag
-    
+
     def testDiscardFlag(self, flag):
         """
         :param int flag: Flag to be tested
         :return: True, if flag is enabled.
 
         .. seealso::
-        
-            :py:meth:`setDiscardFlag()`, :py:meth:`setDiscardFlags()`, 
+
+            :py:meth:`setDiscardFlag()`, :py:meth:`setDiscardFlags()`,
             :py:meth:`discardFlags()`
         """
         return self.__data.discardFlags & flag
-    
+
     def setDiscardFlags(self, flags):
         """
         Set the flags, indicating what to discard from rendering
@@ -130,23 +141,23 @@ class QwtPlotRenderer(QObject):
         :param int flags: Flags
 
         .. seealso::
-        
-            :py:meth:`testDiscardFlag()`, :py:meth:`setDiscardFlag()`, 
+
+            :py:meth:`testDiscardFlag()`, :py:meth:`setDiscardFlag()`,
             :py:meth:`discardFlags()`
         """
         self.__data.discardFlags = flags
-    
+
     def discardFlags(self):
         """
         :return: Flags, indicating what to discard from rendering
 
         .. seealso::
-        
-            :py:meth:`setDiscardFlag()`, :py:meth:`setDiscardFlags()`, 
+
+            :py:meth:`setDiscardFlag()`, :py:meth:`setDiscardFlags()`,
             :py:meth:`testDiscardFlag()`
         """
         return self.__data.discardFlags
-    
+
     def setLayoutFlag(self, flag, on=True):
         """
         Change a layout flag
@@ -154,23 +165,23 @@ class QwtPlotRenderer(QObject):
         :param int flag: Flag to change
 
         .. seealso::
-        
-            :py:meth:`testLayoutFlag()`, :py:meth:`setLayoutFlags()`, 
+
+            :py:meth:`testLayoutFlag()`, :py:meth:`setLayoutFlags()`,
             :py:meth:`layoutFlags()`
         """
         if on:
             self.__data.layoutFlags |= flag
         else:
             self.__data.layoutFlags &= ~flag
-    
+
     def testLayoutFlag(self, flag):
         """
         :param int flag: Flag to be tested
         :return: True, if flag is enabled.
 
         .. seealso::
-        
-            :py:meth:`setLayoutFlag()`, :py:meth:`setLayoutFlags()`, 
+
+            :py:meth:`setLayoutFlag()`, :py:meth:`setLayoutFlags()`,
             :py:meth:`layoutFlags()`
         """
         return self.__data.layoutFlags & flag
@@ -182,31 +193,32 @@ class QwtPlotRenderer(QObject):
         :param int flags: Flags
 
         .. seealso::
-        
-            :py:meth:`setLayoutFlag()`, :py:meth:`testLayoutFlag()`, 
+
+            :py:meth:`setLayoutFlag()`, :py:meth:`testLayoutFlag()`,
             :py:meth:`layoutFlags()`
         """
         self.__data.layoutFlags = flags
-    
+
     def layoutFlags(self):
         """
         :return: Layout flags
 
         .. seealso::
-        
-            :py:meth:`setLayoutFlags()`, :py:meth:`setLayoutFlag()`, 
+
+            :py:meth:`setLayoutFlags()`, :py:meth:`setLayoutFlag()`,
             :py:meth:`testLayoutFlag()`
         """
         return self.__data.layoutFlags
-    
-    def renderDocument(self, plot, filename, sizeMM=(300, 200), resolution=85,
-                       format_=None):
+
+    def renderDocument(
+        self, plot, filename, sizeMM=(300, 200), resolution=85, format_=None
+    ):
         """
         Render a plot to a file
 
         The format of the document will be auto-detected from the
         suffix of the file name.
-  
+
         :param qwt.plot.QwtPlot plot: Plot widget
         :param str fileName: Path of the file, where the document will be stored
         :param QSizeF sizeMM: Size for the document in millimeters
@@ -224,7 +236,7 @@ class QwtPlotRenderer(QObject):
         title = plot.title().text()
         if not title:
             title = "Plot Document"
-        mmToInch = 1./25.4
+        mmToInch = 1.0 / 25.4
         size = sizeMM * mmToInch * resolution
         documentRect = QRectF(0.0, 0.0, size.width(), size.height())
         fmt = format_.lower()
@@ -254,7 +266,7 @@ class QwtPlotRenderer(QObject):
             painter.end()
         elif fmt in QImageWriter.supportedImageFormats():
             imageRect = documentRect.toRect()
-            dotsPerMeter = int(round(resolution*mmToInch*1000.))
+            dotsPerMeter = int(round(resolution * mmToInch * 1000.0))
             image = QImage(imageRect.size(), QImage.Format_ARGB32)
             image.setDotsPerMeterX(dotsPerMeter)
             image.setDotsPerMeterY(dotsPerMeter)
@@ -281,14 +293,11 @@ class QwtPlotRenderer(QObject):
         raster graphics formats.
 
         :param qwt.plot.QwtPlot plot: Plot widget
-        :param str fileName: Path of the file, where the document will be stored
-        :param str format: Format for the document
-        :param QSizeF sizeMM: Size for the document in millimeters.
-        :param int resolution: Resolution in dots per Inch (dpi)
-        
+        :param dest: QPaintDevice, QPrinter or QSvgGenerator instance
+
         .. seealso::
-        
-            :py:meth:`renderTo()`, :py:meth:`render()`, 
+
+            :py:meth:`render()`,
             :py:meth:`qwt.painter.QwtPainter.setRoundingAlignment()`
         """
         if isinstance(dest, QPaintDevice):
@@ -299,18 +308,20 @@ class QwtPlotRenderer(QObject):
             w = dest.width()
             h = dest.height()
             rect = QRectF(0, 0, w, h)
-            aspect = rect.width()/rect.height()
-            if aspect < 1.:
-                rect.setHeight(aspect*rect.width())
+            aspect = rect.width() / rect.height()
+            if aspect < 1.0:
+                rect.setHeight(aspect * rect.width())
         elif isinstance(dest, QSvgGenerator):
             rect = dest.viewBoxF()
             if rect.isEmpty():
                 rect.setRect(0, 0, dest.width(), dest.height())
             if rect.isEmpty():
                 rect.setRect(0, 0, 800, 600)
+        else:
+            raise TypeError("Unsupported destination type %s" % type(dest))
         p = QPainter(dest)
         self.render(plot, p, rect)
-    
+
     def render(self, plot, painter, plotRect):
         """
         Paint the contents of a QwtPlot instance into a given rectangle.
@@ -319,14 +330,18 @@ class QwtPlotRenderer(QObject):
         :param QPainter painter: Painter
         :param str format: Format for the document
         :param QRectF plotRect: Bounding rectangle
-        
+
         .. seealso::
-        
-            :py:meth:`renderDocument()`, :py:meth:`renderTo()`, 
+
+            :py:meth:`renderDocument()`, :py:meth:`renderTo()`,
             :py:meth:`qwt.painter.QwtPainter.setRoundingAlignment()`
         """
-        if painter == 0 or not painter.isActive() or not plotRect.isValid()\
-           or plot.size().isNull():
+        if (
+            painter == 0
+            or not painter.isActive()
+            or not plotRect.isValid()
+            or plot.size().isNull()
+        ):
             return
         if not self.__data.discardFlags & self.DiscardBackground:
             QwtPainter.drawBackground(painter, plotRect, plot)
@@ -335,28 +350,28 @@ class QwtPlotRenderer(QObject):
         #  by the Qt layout system. Therefore we need to calculate the
         #  layout in screen coordinates and paint with a scaled painter.
         transform = QTransform()
-        transform.scale(float(painter.device().logicalDpiX())/plot.logicalDpiX(),
-                        float(painter.device().logicalDpiY())/plot.logicalDpiY())
-        
+        transform.scale(
+            float(painter.device().logicalDpiX()) / plot.logicalDpiX(),
+            float(painter.device().logicalDpiY()) / plot.logicalDpiY(),
+        )
+
         invtrans, _ok = transform.inverted()
         layoutRect = invtrans.mapRect(plotRect)
         if not (self.__data.discardFlags & self.DiscardBackground):
-            left, top, right, bottom = plot.getContentsMargins()
+            left, top, right, bottom = plot.layout().getContentsMargins()
             layoutRect.adjust(left, top, -right, -bottom)
 
         layout = plot.plotLayout()
-        baseLineDists = [None]*QwtPlot.axisCnt
-        canvasMargins = [None]*QwtPlot.axisCnt
+        baseLineDists = canvasMargins = [None] * len(QwtPlot.AXES)
 
-        for axisId in QwtPlot.validAxes:
+        for axisId in QwtPlot.AXES:
             canvasMargins[axisId] = layout.canvasMargin(axisId)
             if self.__data.layoutFlags & self.FrameWithScales:
                 scaleWidget = plot.axisWidget(axisId)
                 if scaleWidget:
-                    baseLineDists[axisId] = scaleWidget.margin()
+                    baseLineDists[axisId] = max(scaleWidget.getContentsMargins())
                     scaleWidget.setMargin(0)
                 if not plot.axisEnabled(axisId):
-                    left, right, top, bottom = 0, 0, 0, 0
                     #  When we have a scale the frame is painted on
                     #  the position of the backbone - otherwise we
                     #  need to introduce a margin around the canvas
@@ -368,22 +383,23 @@ class QwtPlotRenderer(QObject):
                         layoutRect.adjust(0, 1, 0, 0)
                     elif axisId == QwtPlot.xBottom:
                         layoutRect.adjust(0, 0, 0, -1)
-                    layoutRect.adjust(left, top, right, bottom)
-        
+
         #  Calculate the layout for the document.
         layoutOptions = QwtPlotLayout.IgnoreScrollbars
-        
-        if self.__data.layoutFlags & self.FrameWithScales or\
-           self.__data.discardFlags & self.DiscardCanvasFrame:
+
+        if (
+            self.__data.layoutFlags & self.FrameWithScales
+            or self.__data.discardFlags & self.DiscardCanvasFrame
+        ):
             layoutOptions |= QwtPlotLayout.IgnoreFrames
-        
+
         if self.__data.discardFlags & self.DiscardLegend:
             layoutOptions |= QwtPlotLayout.IgnoreLegend
         if self.__data.discardFlags & self.DiscardTitle:
             layoutOptions |= QwtPlotLayout.IgnoreTitle
         if self.__data.discardFlags & self.DiscardFooter:
             layoutOptions |= QwtPlotLayout.IgnoreFooter
-        
+
         layout.activate(plot, layoutRect, layoutOptions)
 
         maps = self.buildCanvasMaps(plot, layout.canvasRect())
@@ -392,35 +408,45 @@ class QwtPlotRenderer(QObject):
             #  have been changed
             layout.activate(plot, layoutRect, layoutOptions)
             maps = self.buildCanvasMaps(plot, layout.canvasRect())
-        
+
         painter.save()
         painter.setWorldTransform(transform, True)
-        
+
         self.renderCanvas(plot, painter, layout.canvasRect(), maps)
-        
-        if (not self.__data.discardFlags & self.DiscardTitle) and\
-           plot.titleLabel().text():
+
+        if (
+            not self.__data.discardFlags & self.DiscardTitle
+        ) and plot.titleLabel().text():
             self.renderTitle(plot, painter, layout.titleRect())
-        
-        if (not self.__data.discardFlags & self.DiscardFooter) and\
-           plot.titleLabel().text():
+
+        if (
+            not self.__data.discardFlags & self.DiscardFooter
+        ) and plot.titleLabel().text():
             self.renderFooter(plot, painter, layout.footerRect())
-            
-        if (not self.__data.discardFlags & self.DiscardLegend) and\
-           plot.titleLabel().text():
+
+        if (
+            not self.__data.discardFlags & self.DiscardLegend
+        ) and plot.titleLabel().text():
             self.renderLegend(plot, painter, layout.legendRect())
-            
-        for axisId in QwtPlot.validAxes:
+
+        for axisId in QwtPlot.AXES:
             scaleWidget = plot.axisWidget(axisId)
             if scaleWidget:
-                baseDist = scaleWidget.margin()
+                baseDist = max(scaleWidget.getContentsMargins())
                 startDist, endDist = scaleWidget.getBorderDistHint()
-                self.renderScale(plot, painter, axisId, startDist, endDist,
-                                 baseDist, layout.scaleRect(axisId))
-        
+                self.renderScale(
+                    plot,
+                    painter,
+                    axisId,
+                    startDist,
+                    endDist,
+                    baseDist,
+                    layout.scaleRect(axisId),
+                )
+
         painter.restore()
-        
-        for axisId in QwtPlot.validAxes:
+
+        for axisId in QwtPlot.AXES:
             if self.__data.layoutFlags & self.FrameWithScales:
                 scaleWidget = plot.axisWidget(axisId)
                 if scaleWidget:
@@ -428,7 +454,7 @@ class QwtPlotRenderer(QObject):
             layout.setCanvasMargin(canvasMargins[axisId])
 
         layout.invalidate()
-    
+
     def renderTitle(self, plot, painter, rect):
         """
         Render the title into a given rectangle.
@@ -441,7 +467,7 @@ class QwtPlotRenderer(QObject):
         color = plot.titleLabel().palette().color(QPalette.Active, QPalette.Text)
         painter.setPen(color)
         plot.titleLabel().text().draw(painter, rect)
-    
+
     def renderFooter(self, plot, painter, rect):
         """
         Render the footer into a given rectangle.
@@ -454,7 +480,7 @@ class QwtPlotRenderer(QObject):
         color = plot.footerLabel().palette().color(QPalette.Active, QPalette.Text)
         painter.setPen(color)
         plot.footerLabel().text().draw(painter, rect)
-    
+
     def renderLegend(self, plot, painter, rect):
         """
         Render the legend into a given rectangle.
@@ -466,9 +492,8 @@ class QwtPlotRenderer(QObject):
         if plot.legend():
             fillBackground = not self.__data.discardFlags & self.DiscardBackground
             plot.legend().renderLegend(painter, rect, fillBackground)
-        
-    def renderScale(self, plot, painter, axisId, startDist, endDist,
-                    baseDist, rect):
+
+    def renderScale(self, plot, painter, axisId, startDist, endDist, baseDist, rect):
         """
         Paint a scale into a given rectangle.
         Paint the scale into a given rectangle.
@@ -503,12 +528,12 @@ class QwtPlotRenderer(QObject):
             y = rect.bottom() - 1.0 - baseDist
             w = rect.width() - startDist - endDist
             align = QwtScaleDraw.TopScale
-        elif axisId == QwtPlot.xBottom:
+        else:  # QwtPlot.xBottom
             x = rect.left() + startDist
             y = rect.top() + baseDist
             w = rect.width() - startDist - endDist
             align = QwtScaleDraw.BottomScale
-        
+
         scaleWidget.drawTitle(painter, align, rect)
         painter.setFont(scaleWidget.font())
         sd = scaleWidget.scaleDraw()
@@ -522,7 +547,7 @@ class QwtPlotRenderer(QObject):
         sd.move(sdPos)
         sd.setLength(sdLength)
         painter.restore()
-        
+
     def renderCanvas(self, plot, painter, canvasRect, maps):
         """
         Render the canvas into a given rectangle.
@@ -533,10 +558,10 @@ class QwtPlotRenderer(QObject):
         :param QRectF rect: Bounding rectangle
         """
         canvas = plot.canvas()
-        r = canvasRect.adjusted(0., 0., -1., 1.)
+        r = canvasRect.adjusted(0.0, 0.0, -1.0, 1.0)
         if self.__data.layoutFlags & self.FrameWithScales:
             painter.save()
-            r.adjust(-1., -1., 1., 1.)
+            r.adjust(-1.0, -1.0, 1.0, 1.0)
             painter.setPen(QPen(Qt.black))
             if not (self.__data.discardFlags & self.DiscardCanvasBackground):
                 bgBrush = canvas.palette().brush(plot.backgroundRole())
@@ -567,8 +592,9 @@ class QwtPlotRenderer(QObject):
             if not self.__data.discardFlags & self.DiscardCanvasFrame:
                 frameWidth = canvas.frameWidth()
                 clipPath = qwtCanvasClip(canvas, canvasRect)
-            innerRect = canvasRect.adjusted(frameWidth, frameWidth,
-                                            -frameWidth, -frameWidth)
+            innerRect = canvasRect.adjusted(
+                frameWidth, frameWidth, -frameWidth, -frameWidth
+            )
             painter.save()
             if clipPath.isEmpty():
                 painter.setClipRect(innerRect)
@@ -581,17 +607,28 @@ class QwtPlotRenderer(QObject):
             if frameWidth > 0:
                 painter.save()
                 frameStyle = canvas.frameShadow() | canvas.frameShape()
-                frameWidth = canvas.frameWidth()
-                borderRadius = canvas.borderRadius()
-                if borderRadius > 0.:
-                    QwtPainter.drawRoundedFrame(painter, canvasRect, r, r,
-                                                canvas.palette(), frameWidth,
-                                                frameStyle)
+                radius = canvas.borderRadius()
+                if radius > 0.0:
+                    QwtPainter.drawRoundedFrame(
+                        painter,
+                        canvasRect,
+                        radius,
+                        radius,
+                        canvas.palette(),
+                        frameWidth,
+                        frameStyle,
+                    )
                 else:
                     midLineWidth = canvas.midLineWidth()
-                    QwtPainter.drawFrame(painter, canvasRect, canvas.palette(),
-                                         canvas.foregroundRole(), frameWidth,
-                                         midLineWidth, frameStyle)
+                    QwtPainter.drawFrame(
+                        painter,
+                        canvasRect,
+                        canvas.palette(),
+                        canvas.foregroundRole(),
+                        frameWidth,
+                        midLineWidth,
+                        frameStyle,
+                    )
                 painter.restore()
 
     def buildCanvasMaps(self, plot, canvasRect):
@@ -603,10 +640,9 @@ class QwtPlotRenderer(QObject):
         :return: Calculated scale maps
         """
         maps = []
-        for axisId in QwtPlot.validAxes:
+        for axisId in QwtPlot.AXES:
             map_ = QwtScaleMap()
-            map_.setTransformation(
-                                plot.axisScaleEngine(axisId).transformation())
+            map_.setTransformation(plot.axisScaleEngine(axisId).transformation())
             sd = plot.axisScaleDiv(axisId)
             map_.setScaleInterval(sd.lowerBound(), sd.upperBound())
             if plot.axisEnabled(axisId):
@@ -631,17 +667,17 @@ class QwtPlotRenderer(QObject):
             map_.setPaintInterval(from_, to)
             maps.append(map_)
         return maps
-            
+
     def updateCanvasMargins(self, plot, canvasRect, maps):
         margins = plot.getCanvasMarginsHint(maps, canvasRect)
         marginsChanged = False
-        for axisId in QwtPlot.validAxes:
-            if margins[axisId] >= 0.:
-                m = np.ceil(margins[axisId])
+        for axisId in QwtPlot.AXES:
+            if margins[axisId] >= 0.0:
+                m = math.ceil(margins[axisId])
                 plot.plotLayout().setCanvasMargin(m, axisId)
                 marginsChanged = True
         return marginsChanged
-    
+
     def exportTo(self, plot, documentname, sizeMM=None, resolution=85):
         """
         Execute a file dialog and render the plot to the selected file
@@ -651,9 +687,9 @@ class QwtPlotRenderer(QObject):
         :param QSizeF sizeMM: Size for the document in millimeters
         :param int resolution: Resolution in dots per Inch (dpi)
         :return: True, when exporting was successful
-        
+
         .. seealso::
-        
+
             :py:meth:`renderDocument()`
         """
         if plot is None:
@@ -662,21 +698,27 @@ class QwtPlotRenderer(QObject):
             sizeMM = QSizeF(300, 200)
         filename = documentname
         imageFormats = QImageWriter.supportedImageFormats()
-        filter_ = ["PDF documents (*.pdf)",
-                   "SVG documents (*.svg)",
-                   "Postscript documents (*.ps)"]
+        filter_ = [
+            "PDF documents (*.pdf)",
+            "SVG documents (*.svg)",
+            "Postscript documents (*.ps)",
+        ]
         if imageFormats:
             imageFilter = "Images"
             imageFilter += " ("
             for idx, fmt in enumerate(imageFormats):
                 if idx > 0:
                     imageFilter += " "
-                imageFilter += "*."+str(fmt)
+                imageFilter += "*." + str(fmt)
             imageFilter += ")"
             filter_ += [imageFilter]
-        filename, _s = getsavefilename(plot, "Export File Name", filename,
-                                   ";;".join(filter_),
-                                   options=QFileDialog.DontConfirmOverwrite)
+        filename, _s = getsavefilename(
+            plot,
+            "Export File Name",
+            filename,
+            ";;".join(filter_),
+            options=QFileDialog.DontConfirmOverwrite,
+        )
         if not filename:
             return False
         self.renderDocument(plot, filename, sizeMM, resolution)
